sample_test_with_naarad_run_tests_in_parallel_20150111_225227

### sample_config1 : test0

Result | Function execution time | Total execution time
--- | --- | ---
Failed | Finished with error | 5.1499710083 sec

Error message:
Other messages: Traceback (most recent call last): File "/Users/jehrlich/workspace/zopkio/zopkio/test_runner.py", line 260, in run_test_command test.function() File "/Users/jehrlich/workspace/zopkio/test/samples/sample_test_with_naarad_run_tests_in_parallel.py", line 78, in test0 assert 1 == 2 AssertionError

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
sample-perf | qps | mean lt 10.0 | None
sample-perf | latency | p99 lt 300.0 | None
sample-perf | latency | p50 lt 250.0 | None
sample-perf | latency | mean lt 125.0 | None